TextSection

Struct TextSection 

pub struct TextSection<'f, 'p> { /* private fields */ }
A text section that is drawn on an area of a PDF layer.

Implementations

Source

impl<'f, 'p> TextSection<'f, 'p>

pub fn add_newline(&mut self) -> bool

Tries to add a new line and returns true if the area was large enough to fit the new line.

pub fn print_str( &mut self, s: impl AsRef<str>, style: Style, ) -> Result<(), Error>

Prints the given string with the given style.

The font cache for this text section must contain the PDF font for the given style.

Adds a clickable link with the given text, URI, and style.

The font cache for this text section must contain the PDF font for the given style.