RenderResult

Struct RenderResult 

pub struct RenderResult {
    pub size: Size,
    pub has_more: bool,
}
The result of the rendering process.

This struct is returned by implementations of the Element::render method. It contains the size of the area that has been written to (measured from the origin of the area that was provided to the render method) and information about additional content that did not fit in the provided area.

See the Rendering Process section of the crate documentation for more information on the rendering process.

Fields

size: Size

The size of the area that has been written to, starting from the origin of the provided area.

has_more: bool

Indicates whether the element contains more content that did not fit in the provided area.