LineStyle

Struct LineStyle 

pub struct LineStyle { /* private fields */ }
A style for a line, used in styling borders and shapes.

The style consists of:

  • the line thickness in millimeters (defaults to 0.1)
  • the color of the line, see Color (defaults to black)

Note that a line thickness of 0.0 does not make the line disappear, but rather makes it appear 1px wide across all devices and resolutions.

Implementations

Source

impl LineStyle

pub fn new() -> LineStyle

Creates a new line style with default values.

pub fn set_thickness(&mut self, thickness: impl Into<Mm>)

Sets the line thickness.

Setting this to 0.0 will not hide the line, rather it’s a special value that tells PDF viewers to render the line as 1px regardless of the display size and zoom.

pub fn with_thickness(self, thickness: impl Into<Mm>) -> Self

Sets the line thickness and returns the line style.

Setting this to 0.0 will not hide the line, rather it’s a special value that tells PDF viewers to render the line as 1px regardless of the display size and zoom.

pub fn thickness(&self) -> Mm

Returns the line thickness.

pub fn set_color(&mut self, color: Color)

Sets the line color.

pub fn with_color(self, color: Color) -> Self

Sets the line color and returns the line style.

pub fn color(&self) -> Color

Returns the line color.