StyledString

Struct StyledString 

pub struct StyledString {
    pub s: String,
    pub style: Style,
    pub link: Option<String>,
}
A String with a Style annotation.

Example

use genpdfi::style;
let ss1 = style::StyledString::new("bold".to_owned(), style::Effect::Bold, None);
let ss2 = style::StyledString::new("red".to_owned(), style::Color::Rgb(255, 0, 0), None);

Fields

s: String

The annotated string.

style: Style

The style annotation.

link: Option<String>

The link annotation.

Implementations

Source

impl StyledString

pub fn new( s: impl Into<String>, style: impl Into<Style>, link: Option<String>, ) -> StyledString

Creates a new styled string from the given string and style.

pub fn width(&self, font_cache: &FontCache) -> Mm

Calculates the width of the this string with this style using the data in the given font cache.

If the font family is set for the style, it must have been created by the given FontCache.