pub struct TextSection<'f, 'p> { /* private fields */ }Expand description
A text section that is drawn on an area of a PDF layer.
Implementations
Sourceimpl<'f, 'p> TextSection<'f, 'p>
impl<'f, 'p> TextSection<'f, 'p>
Sourcepub fn add_newline(&mut self) -> bool
pub fn add_newline(&mut self) -> bool
Tries to add a new line and returns true if the area was large enough to fit the new
line.